@@ -11,7 +11,7 @@ pub struct BlockModeError;
 pub struct InvalidKeyIvLength;
 
 impl fmt::Display for BlockModeError {
-    fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
         f.write_str("BlockModeError")
     }
 }
@@ -24,14 +24,10 @@ impl error::Error for BlockModeError {
 }
 
 impl fmt::Display for InvalidKeyIvLength {
-    fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
         f.write_str("InvalidKeyIvLength")
     }
 }
 
 #[cfg(feature = "std")]
-impl error::Error for InvalidKeyIvLength {
-    fn description(&self) -> &str {
-        "invalid key or IV length during block cipher mode initialization"
-    }
-}
+impl error::Error for InvalidKeyIvLength {}
